#!/bin/sh
#
# LOG_ROTATE.SH: Addresses inadequacies of cron and Apache's rotatelogs.
#                See 'log_rotate.txt.asc' for more details.
#
PATH=""                        # Empty PATH environment
ACCL="access_log"              # Apache default access_log
ERRL="error_log"               # Apache default error_log
DIR1="/usr/local/apache"       # Main Apache directory
BIN1="/usr/bin"                # First binary directory
BIN2="/usr/local/bin"          # Second binary directory
BIN3="$DIR1/bin/apachectl"     # Third binary
DATE=`$BIN1/date +%Y-%m-%d`    # Get current date (end of month)
MNYR=`$BIN1/date "+%B %Y"`     # Get human-readable date
TEST=`TZ=MET+4 $BIN1/date +%d` # Test value
ACC1="$DIR1/logs/$ACCL"        # Original access_log
ACC2="${ACC1}.${DATE}"         # Archived access_log
ERR1="$DIR1/logs/$ERRL"        # Original error_log
ERR2="${ERR1}.${DATE}"         # Archived error_log
NULL="/dev/null"               # Null value to purge $ACC1 and $ERR1
CUT1="$BIN1/cut -b34-100"      # Cut position variable
#
if test $TEST = 01
  then
    $BIN1/echo "\nPerforming monthly httpd log archival procedure...\n"
    $BIN1/date
    $BIN1/echo "\n 1.  Stopping Apache...\n     \c"
    $BIN3 stop
    $BIN1/echo " 2.  Archiving logfiles for ${MNYR}...\n     \c"
    $BIN1/ls -al $ACC1 |$CUT1
    $BIN1/echo "     \c"
    $BIN1/ls -al $ERR1 |$CUT1
    $BIN1/echo " 3.  $BIN1/cp -p $ACC1\n                    $ACC2"
    $BIN1/cp -p $ACC1 $ACC2
    if [ ! -f $ACC2 ]; then
      $BIN1/echo "ERROR!: $ACC2 was not created!  Aborting..."
      $BIN1/echo "Restarting Apache..."
      $BIN3 start
      exit 1
    fi
    $BIN1/echo " 4.  $BIN1/cat $NULL > $ACC1"
    $BIN1/cat $NULL > $ACC1
    $BIN1/echo " 5.  $BIN1/cp -p $ERR1\n                    $ERR2"
    $BIN1/cp -p $ERR1 $ERR2
    if [ ! -f $ERR2 ]; then
      $BIN1/echo "ERROR!: $ERR2 was not created!  Aborting..."
      $BIN1/echo "Restarting Apache..."
      $BIN3 start
      exit 1
    fi
    $BIN1/echo " 6.  $BIN1/cat $NULL > $ERR1"
    $BIN1/cat $NULL > $ERR1
    VAR1=`$BIN1/date +%S`
    VAR2=`$BIN1/expr 61 - $VAR1`
    $BIN1/echo " 7.  Sleeping for $VAR2 seconds..."
    $BIN1/sleep $VAR2
    $BIN1/echo " 8.  Restarting Apache...\n     \c"
    $BIN3 start
    $BIN1/echo "     \c"
    $BIN1/date
    $BIN1/echo " 9.  Compressing $ACC2...\c"
    $BIN2/gzip $ACC2
    $BIN1/echo "done.\n      \c"
    $BIN1/ls -al ${ACC2}.gz |$CUT1
    $BIN1/echo "10.  Compressing $ERR2...\c"
    $BIN2/gzip $ERR2
    $BIN1/echo "done.\n      \c"
    $BIN1/ls -al ${ERR2}.gz |$CUT1
    $BIN1/echo "\nRun complete.\n"
  else
    $BIN1/echo "Today is not the last day of the month for ${MNYR}."
fi
